<?php
/**
 * Created by PhpStorm.
 * User: Narendra Kumar
 * Date: 30-11-2017
 * Time: 11:48 AM
 */

class HelperMethods
{
  /**
   * @param $request
   * @param $response
   * @param array $required_field
   * @return mixed
   */
  public static function verifyRequiredParams($request, $response, $required_fields)
  {
    $error = false;
    $errorFields = "";
    $requestParams = $request->getParsedBody();
    foreach ($required_fields as $field) {
      if (!isset($requestParams[$field]) || (is_array($requestParams[$field]) && count($requestParams[$field]) == 0) || (!is_array($requestParams[$field]) && strlen(trim($requestParams[$field])) <= 0)) {
        $error = true;
        $errorFields .= $field . ', ';
      }
    }
    if ($error) {
      $output = self::prepareResponse(Status::FAILED, BusinessMessages::getMessage(BusinessMessages::MISSING_PARAMS) . substr($errorFields, 0, -2));
      return $response->withJson($output, ResponseCode::BAD_REQUEST);
    }
  }

  public static function getRequestParam($request, $param)
  {
    if (isset($request->getParsedBody()[$param])) {
      return $request->getParsedBody()[$param];
    }
    return NULL;
  }

  public static function prepareResponse($status, $message, $data = array())
  {
    $data = is_array($data) || is_object($data) ? $data : array();
    $response['status'] = $status;
    $response['msg'] = $message;
    if (count($data) > 0) {
      $response['data'] = array();
      array_push($response['data'], $data);
    } else {
      $response['data'] = array();
    }
    return $response;
  }

  public static function handleException($response, $e, $test = null)
  {
    error_log($e->getMessage());
    $errorMessage = $e->getMessage();
    //$errorCode = $e->getCode();
    $output = self::prepareResponse(Status::FAILED, trim($errorMessage));

    if ($e instanceof SecurityException)
      return $response->withJson($output, ResponseCode::UNAUTHORISED);
    elseif ($e instanceof ValidationException)
      return $response->withJson($output, ResponseCode::BAD_REQUEST);
    elseif ($e instanceof PDOException) {
      //$errorMessage = $test;
      $errorMessage = str_replace('SQLSTATE[ERROR]:', '', $errorMessage);
      $errorMessage = str_replace('<<Unknown error', '', $errorMessage);
      $errorMessage = str_replace('>>:', '', $errorMessage);
      // $errorMessage = preg_replace('/[0-9]+/', '', $errorMessage);
      $errorDetails = explode(' ', trim($errorMessage), 2);
      $output = HelperMethods::prepareResponse(Status::FAILED, trim($errorDetails[1]));

      //$output = HelperMethods::prepareResponse(Status::FAILED, $e->getCode() . ":" . trim($errorMessage));
      return $response->withJson($output, ResponseCode::BAD_REQUEST);
    } elseif ($e instanceof Exception) {
      return $response->withJson($output, ResponseCode::BAD_REQUEST);
    }
  }

  public static function getColumnValue($row, $columnName, $dataType)
  {
    switch ($dataType) {
      // For integer
      case DataType::INTEGER:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? intval($row[$columnName]) : 0;
      case DataType::DOUBLE:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? round($row[$columnName], 2) : 0.00;
      // For String
      case DataType::STRING:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? trim($row[$columnName]) : "";
      // For Datetime
      case DataType::DATETIME:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? trim($row[$columnName]) : "0000-00-00 00:00:00";
      // For Date
      case DataType::DATE:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? trim($row[$columnName]) : "0000-00-00";
      // For Time
      case DataType::TIME:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? trim($row[$columnName]) : "00:00:00";
      case DataType::LONG_DOUBLE:
        return isset($row[$columnName]) || array_key_exists($columnName, $row) ? round($row[$columnName], 6) : 0.000000;
      default:
        return "";
    }
  }

  public static function generateVerificationCode()
  {
    // Generate a 4 digit random number
    return mt_rand(1001, 9999);
  }

  public static function getPasswordHash($password)
  {
    $hash = password_hash($password, PASSWORD_BCRYPT);
    return $hash;
  }

  public static function createJwtToken($data)
  {
    $tokenId = base64_encode(openssl_random_pseudo_bytes(32));
    $issuedAt = time();
    $notBefore = $issuedAt;
    $expire = $notBefore + (60 * 60 * 24 * 365);   // Adding 1 Year
    $serverName = 'dexconsulting.com';       // Retrieve the server name from config file
    $secretValue = '425413171420194';

    /*
     * Create the token as an array
     */
    $data = [
      'iat' => $issuedAt,         // Issued at: time when the token was generated
      'jti' => $tokenId,          // Json Token Id: an unique identifier for the token
      'iss' => $serverName,       // Issuer
      'nbf' => $notBefore,        // Not before
      'exp' => $expire,           // Expire
      'data' => $data
    ];

    $jwt = \Firebase\JWT\JWT::encode(
      $data,          //Data to be encoded in the JWT
      $secretValue,   // The signing key
      'HS512'     // Algorithm used to sign the token, see https://tools.ietf.org/html/draft-ietf-jose-json-web-algorithms-40#section-3
    );
    return $jwt;
  }

  /**
   * @param $base64String
   * @param $imageName , without extension
   * @param $path , where to upload image
   * @return string
   * @throws Exception
   * @api Save base64 Image
   */
  public static function saveBase64Image($base64String, $imageName, $path)
  {
    if (preg_match('/^data:image\/(\w+);base64,/', $base64String, $type)) {
      $base64String = substr($base64String, strpos($base64String, ',') + 1);
      $type = strtolower($type[1]); // jpg, png, gif
      if (!in_array($type, ['bmp', 'jpg', 'jpeg', 'gif', 'png'])) {
        throw new Exception('Invalid image type');
      }
      $base64String = base64_decode($base64String);
      if ($base64String === false) {
        throw new Exception('Base64_decode failed');
      }
    } else {
      throw new Exception('Did not match data URI with image data');
    }
    if (!file_exists($path)) {
      mkdir($path, 0777, true);
    }
    $fh = fopen($path.$imageName, 'w+');
    fwrite($fh, $base64String);
    fclose($fh);
//    file_put_contents($path . $imageName, $base64String);
    return $imageName;
  }

  public static function generateRandomString($length = 10)
  {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
      $randomString .= $characters[rand(0, $charactersLength - 1)];
    }
    return $randomString;
  }

  public static function generateGuid($opt = true)
  {       //  Set to true/false as your default way to do this.

    if (function_exists('com_create_guid')) {
      if ($opt) {
        return com_create_guid();
      } else {
        return trim(com_create_guid(), '{}');
      }
    } else {
      mt_srand((double)microtime() * 10000);    // optional for php 4.2.0 and up.
      $charid = strtoupper(md5(uniqid(rand(), true)));
      $hyphen = chr(45);    // "-"
      $left_curly = $opt ? chr(123) : "";     //  "{"
      $right_curly = $opt ? chr(125) : "";    //  "}"
      $uuid = substr($charid, 0, 8) . $hyphen
        . substr($charid, 8, 4) . $hyphen
        . substr($charid, 12, 4) . $hyphen
        . substr($charid, 16, 4) . $hyphen
        . substr($charid, 20, 12);

      return $uuid;
    }
  }

  public static function getDrivingDistance($lat1, $long1, $lat2, $long2, $googleAPIKey, $distanceUnit = 'metric', $language = 'en')
  {
    echo $url = "https://maps.googleapis.com/maps/api/distancematrix/json?units=" . $distanceUnit . "&origins=" . $lat1 . "," . $long1 . "&destinations=" . $lat2 . "," . $long2 . "&mode=driving&key=" . $googleAPIKey . "&language=" . $language;
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_PROXYPORT, 3128);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
    $response = curl_exec($ch);
    curl_close($ch);
    $response_a = json_decode($response, true);

    $dist = 0;
    if (isset($response_a['rows'][0]['elements'][0]['distance'])) {
      $dist = $response_a['rows'][0]['elements'][0]['distance']['text'];
    }
    $time = 0;
    if (isset($response_a['rows'][0]['elements'][0]['duration'])) {
      $time = $response_a['rows'][0]['elements'][0]['duration']['text'];
    }

    return array('distance' => $dist, 'time' => $time);
  }

  public static function getStaticGmapURLForDirection($origin, $destination, $waypoints, $size = "800x300")
  {
    $markers = array();
    $waypoints_labels = array("A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K");
    $waypoints_label_iter = 0;
    $markers[] = "markers=color:green" . urlencode("|") . "label:" . urlencode($waypoints_labels[$waypoints_label_iter++] . '|' . $origin);
    foreach ($waypoints as $waypoint) {
      $markers[] = "markers=color:blue" . urlencode("|") . "label:" . urlencode($waypoints_labels[$waypoints_label_iter++] . '|' . $waypoint);
    }
    $markers[] = "markers=color:red" . urlencode("|") . "label:" . urlencode($waypoints_labels[$waypoints_label_iter] . '|' . $destination);
    $url = "https://maps.googleapis.com/maps/api/directions/json?origin=$origin&destination=$destination&waypoints=" . implode($waypoints, '|');
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, false);
    $result = curl_exec($ch);
    curl_close($ch);
    $googleDirection = json_decode($result, true);
    $polyline = urlencode($googleDirection['routes'][0]['overview_polyline']['points']);
    $markers = implode($markers, '&');

    return "https://maps.googleapis.com/maps/api/staticmap?size=$size&maptype=roadmap&path=enc:$polyline&$markers";
  }

  public static function getStaticGmapURL($origin, $destination, $polyline, $googleAPIKey, $size = "800x300")
  {
    $markers = array();
    $waypoints_labels = array("A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K");
    $waypoints_label_iter = 0;
    $markers[] = "markers=color:green" . urlencode("|") . "label:" . urlencode($waypoints_labels[$waypoints_label_iter++] . '|' . $origin);
    $markers[] = "markers=color:red" . urlencode("|") . "label:" . urlencode($waypoints_labels[$waypoints_label_iter] . '|' . $destination);
    $markers = implode($markers, '&');
    return "https://maps.googleapis.com/maps/api/staticmap?size=$size&maptype=roadmap&path=color:0x00000000|weight:5|enc:$polyline&$markers&key=$googleAPIKey";
  }

  public static function sendMessageWithCSMS($data)
  {
    // $url = "http://csms.advtworld.net/api/sendmessage.php?usr=jahul&pwd=jahul@123&sndr=" . $data->senderId . "&ph=" . $data->phone . "&message=" . urlencode($data->msg);
    $url = "https://www.zareou.com/api/v1/public/index.php/sendSMSToMobile";
    $curl = curl_init();
    $newData = array();
    $newData['mobile'] = $data->phone;
    $newData['text'] = $data->message;
    $newData['dailingCode'] = $data->dailingCode;
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_POST, count($newData));
    curl_setopt($curl, CURLOPT_POSTFIELDS, ($newData));
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
    $result = curl_exec($curl);
    curl_close($curl);
    return $result;
  }
  public static function sendWelcomeMessage($userPhone, $message)
  {
    $url = "http://pro.wsam.zed.com/SmsApi/Demo/Default/EnviarSms?msisdn=" . urlencode($userPhone) . "&texto=" . urlencode($message) . "&idCampana=6936";
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_ENCODING, "gzip");
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)');
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('X-Show-Extended-Info: True'));
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Accept: application/json'));
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Basic RGVtbzpEZW1vU21zQXBp'));

    $retValue = curl_exec($ch);
    $response = json_decode(curl_exec($ch));
    $ee = curl_getinfo($ch);
  }
    public static function sendOtpMessage($data)
    {
       //print_r($data);
       // $url = "https://japi.instaalerts.zone/httpapi/QueryStringReceiver?ver=1.0&key=4nyXz3gK9mpGsdYioNSKcg==&encrpt=0&dest=". $data->phone ."&send=DEXPOS&text=" . urlencode($data->message);
        //$url = "https://japi.instaalerts.zone/httpapi/QueryStringReceiver?ver=1.0&key=4nyXz3gK9mpGsdYioNSKcg==&encrpt=0&dest=". $data->phone ."&send=DEXPOS&text=" . urlencode($data->message);
       // $url = "https://japi.instaalerts.zone/httpapi/QueryStringReceiver?ver=1.0&key=4nyXz3gK9mpGsdYioNSKcg==&encrpt=0&dest=". $data->phone ."&send=DEXPOS&text=" . urlencode($data->message);
       // $url = "https://japi.instaalerts.zone/httpapi/QueryStringReceiver?ver=1.0&key=4nyXz3gK9mpGsdYioNSKcg==&encrpt=0&dest=". $data->phone ."&send=DEXPOS&text=" . urlencode($data->message);
        $url ="https://japi.instaalerts.zone/httpapi/QueryStringReceiver?ver=1.0&key=0SoOGSgNyfs1Sc1pFVO5xw==&encrpt=0&dest=". $data->phone ."&send=CARBLS&text=" . urlencode($data->message);
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 20);
        curl_setopt($ch, CURLOPT_HEADER, 0);

        $result = curl_exec($ch);
        curl_close($ch);
        return $result;
    }
}
