<?php

class AuthManager
{
  private $store = null;

  public function __construct($store = null)
  {
    if (isset($store)) {
      $this->store = $store;
    } else {
      $this->store = new AuthStore();
    }
  }

  public function createUserSession($deviceData)
  {
    return $this->store->createUserSession($deviceData);
  }

  public function isValidUser($user, $password)
  {
    $isValid = 0;
    if ($user != null && password_verify($password, $user->passwordHash))
      $isValid = 1;
    return $isValid;
  }

  public function getUser($userId)
  {
    $dataSet = $this->store->getUser($userId);
    $user = null;
    if (count($dataSet)) {
      $user = Converter::getUserObject($dataSet[0]);
    }
    return $user;
  }

  public function getUserByReferralCode($referralCode) {
    $dataSet = $this->store->getUserByReferralCode($referralCode);
    $user = null;
    if (count($dataSet)) {
      $user = Converter::getUserObject($dataSet[0]);
    }
    return $user;
  }

  public function getUserByToken($token)
  {
    $dataSet = $this->store->getUserByToken($token);
    $user = new stdClass();
    $user->userId = 0;
    $user->appId = 0;
    if (count($dataSet)) {
      $user = Converter::getUserObject($dataSet[0]);
    }
    return $user;
  }

  public function getUserByUsernameAndType($username, $typeId) {
      $dataSet = $this->store->getUserByUsernameAndType($username, $typeId);
      $user = null;
      if (count($dataSet)) {
          $user = Converter::getUserObject($dataSet[0]);
      }
      return $user;
  }

  public function getUserByUsername($username) {
    $dataSet = $this->store->getUserByUsername($username);
    $user = null;
    if (count($dataSet)) {
      $user = Converter::getUserObject($dataSet[0]);
    }
    return $user;
  }

  public function getUserByUserIdAndType($userId, $typeId)
  {
    $dataSet = $this->store->getUserByUserIdAndType($userId, $typeId);
    $user = null;
    if (count($dataSet)) {
      $user = Converter::getUserObject($dataSet[0]);
    }
    return $user;
  }

  public function getUserByUserIdAndTypeNew($userId, $typeId)
  {
    $dataSet = $this->store->getUserByUserIdAndTypeNew($userId, $typeId);
    $user = null;
    if (count($dataSet)) {
      $user = $dataSet[0];
    }
    return $user;
  }

  public function checkIfDriverAlreadyLogin($userId)
  {
    return $this->store->checkIfDriverAlreadyLogin($userId);
  }

  public function sendVerificationCode($appId, $verificationCode, $phoneNumber)
  {
    try {
      $message = "Your Zareou Verification Code is " . $verificationCode;
      $response = TwilioManager::sendMessage($appId, $phoneNumber, $message);
    } catch (Exception $e) {
      //echo $e->getMessage();
    } finally {
      return true;
    }
  }

  public function updateUserVerificationCode($verificationCode, $userId)
  {
    return $this->store->updateUserVerificationCode($verificationCode, $userId);
  }

  public function updatePhoneVerifiedFlag($userId, $newPhone, $verifiedFlag)
  {
    return $this->store->updatePhoneVerifiedFlag($userId, $newPhone, $verifiedFlag);
  }

  public function getDriverLoginData($userId)
  {
    $dataSet = $this->store->getDriverLoginData($userId);
    $totalDataSets = count($dataSet);
    $driverData = new stdClass();
    $driverData->basicProfile = null;
    $driverData->vehicles = [];

    if ($totalDataSets > 0 && count($dataSet[0])) {
      $driverData->basicProfile = Converter::getDriverObject($dataSet[0][0]);
    }

    if ($totalDataSets > 1 && count($dataSet[1])) {
      foreach ($dataSet[1] as $row) {
        $driverData->vehicles[] = Converter::getVehicleObject($row);
      }
    }
    return $driverData;
  }

  public function registerPassenger($passenger)
  {
    $dataSet = $this->store->registerPassenger($passenger);
    if (count($dataSet)) {

      if ($passenger->referralCode) {
        $user = $this->getUserByReferralCode($passenger->referralCode);
        // Inform user via text message, that his friend has joined the network.
        TwilioManager::sendMessage($passenger->appId, $user->dialingCode . $user->phone, "Congratulations, Your friend " . $passenger->firstName . " has joined your Zareou Network.");
        // Inform user via email, that his friend has joined the network.
        EmailManager::sendMail($passenger->appId, $user->email, "", "Your friend has joined your Zareou Network.", "Congratulations.. Your friend " . $passenger->firstName . " has joined your Zareou Network");
      }

      $passenger->userId = $dataSet[0][CommonDbColumns::$userId];
      $passenger->passengerId = $dataSet[0][CommonDbColumns::$passengerId];
      $passenger->referralCode = $dataSet[0][CommonDbColumns::$referralCode];

      // Prepare JWT data part
      $data = array("userId" => $passenger->userId, "appId" => $passenger->appId, "typeId" => $passenger->userTypeId);

      // Crete JWT
      $passenger->token = HelperMethods::createJwtToken($data);
      $passenger->invitationUrl = str_replace("{{referralCode}}", $passenger->referralCode, Configuration::getConfiguration($passenger->appId, Configuration::INVITATION_URL));

      // Create driver session
      $this->store->createUserSession($passenger);

      // Send OTP to driver's mobile
      $mobileNumber = $passenger->dialingCode . $passenger->phone;
      $this->sendVerificationCode($passenger->appId, $passenger->verificationCode, $mobileNumber);

      // Send Email about registration.
      $subject = "Registration Success";
      $emailBody = EmailTemplate::prepareRegistrationTemplate();
      EmailManager::sendMail($passenger->appId, $passenger->email, $passenger->firstName . " " . $passenger->lastName, $subject, $emailBody);
      $passengerManager = new PassengerManager();
      $response = $passengerManager->getPassengerProfile($passenger->userId);
      $response->token = $passenger->token;
    }

    return $response;
  }

  public function getUserPaymentCards($userId)
  {
    $dataSet = $this->store->getUserPaymentCards($userId);
    $paymentCards["paymentCards"] = array();
    if (count($dataSet)) {
      foreach ($dataSet as $row) {
        $paymentCards["paymentCards"][] = Converter::getPaymentCardObject($row);
      }
    }
    return $paymentCards;
  }

  public function addPaymentCard($newPaymentCard)
  {
    $dataSet = $this->store->addPaymentCard($newPaymentCard);
    $paymentCard["paymentCard"] = array();
    if (count($dataSet)) {
      foreach ($dataSet as $row) {
        $paymentCard["paymentCard"] = Converter::getPaymentCardObject($row);
      }
    }
    return $paymentCard;
  }

  public function sendResetPasswordEmailLink($email, $appId, $typeId)
  {
    $user = $this->getUserByUsernameAndType($email, $typeId);
    $actionResult = 0;
    if ($user) {
      $cd = HelperMethods::generateRandomString(12);
      $uid = HelperMethods::generateGuid();
      $isDone = $this->store->updateResetToken($user->userId, $typeId, $uid, $cd);
      if ($isDone) {
        $link = sprintf(URLS::$PasswordResetUrl, $uid, $cd);
        $subject = "Password Reset Request";
        $body = "<p>Hello,</p>";
        $body .= "<p>You have required to change the password of your account. Please click on the following link and follow instructions.</p></br>";
        $body .= "<p><a href='" . $link . "'>Click here to reset password</a></p><br/><br/>";
        $body .= "Zareou Team";
        $emailManager = new EmailManager();
        $actionResult = $emailManager::sendMail($appId, $email, $email, $subject, $body);
      }
    }
    return $actionResult;
  }

  public function changePassword($token, $cd, $password)
  {
    $hash = HelperMethods::getPasswordHash($password);
    return $this->store->changePassword($token, $cd, $hash);
  }

  public function updateUserPassword($userId, $typeId, $passwordText)
  {
    $hash = HelperMethods::getPasswordHash($passwordText);
    return $this->store->updateUserPassword($userId, $typeId, $passwordText, $hash);
  }


  public function updateUserAppLanguage($data)
  {
    return $this->store->updateUserAppLanguage($data);

  }

  public function verifyDriverPhoneCode($data)
  {
    return $this->store->verifyDriverPhoneCode($data);

  }

  //new data

  public function registerCustomer($users)
  {
    $dataSet = $this->store->registerCustomer($users);
    $result = array();
    if (count($dataSet)) {
        $result['details'] = Converter::getCustomerSignupDetailsObject($dataSet);
        $userId = $result['details'][0];
        if ($userId['isPasswordAvailable']== 0) {
            $data = new stdClass();
            $data->phone = $userId['mobile'];
           // $data->message = "Login OTP " . $userId['otp'] ;
            $data->message = "Your Carblushh login OTP is " . $userId['otp'] . " ,. Keep Blushing!";
            $data->dailingCode = $userId['dialingCode'];
           // $data->message = "Login OTP." . HelperMethods::generateVerificationCode();
            HelperMethods::sendOtpMessage($data);
        }
    }
    return $result;
  }
//    public function loginUser($customer)
//    {
//        $dataSet = $this->store->loginUser($customer);
////        print_r($dataSet);
//        $result = array();
//        if (count($dataSet)) {
//            $result['details'] = Converter::getUserDetailsList($dataSet);
//        }
//        return $result;
//    }

    public function loginSuperAdmin($admin) {
        $dataSet = $this->store->loginSuperAdmin($admin);
        $result = array();
        if (count($dataSet)) {
            $result['details'] = Converter::getLoginDetails($dataSet);
        }
        return $result;
    }

    public function createBusiness($business) {
        $dataSet = $this->store->createBusiness($business);
        $result = array();
        if (count($dataSet)) {
            $result['details'] = Converter::getBusinessDetails($dataSet);
        }
        return $result;
    }
    public function loginCustomer($customer) {
        $dataSet = $this->store->loginCustomer($customer);
        $result = array();
        if (count($dataSet)) {
            $result['details'] = Converter::getLoginDetails($dataSet);
        }
        return $result;
    }
    public function loginAuditor($auditor) {
         //print_r($auditor);
        $dataSet = $this->store->loginAuditor($auditor);
        $result = array();
        if (count($dataSet)) {
            $result['details'] = Converter::getLoginDetails($dataSet);
        }
        return $result;
    }
}
